@@ -1,9 +1,15 @@
 #!/usr/bin/env python
 # coding: utf-8
 
+import pytest
+import sys
 from ...msgpack import packb, unpackb
 
 
+
+@pytest.mark.skipif(
+    sys.version_info[0] == 2, reason="frombytes instead of fromstring not supported"
+)
 def test_unpack_buffer():
     from array import array
     buf = array('b')
